@@ -52,7 +52,7 @@ class Exceptions:
 
 class FinSpaceDataClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.89/reference/services/finspace-data.html#FinSpaceData.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/finspace-data.html#FinSpaceData.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/client.html)
     """
 
@@ -61,7 +61,7 @@ class FinSpaceDataClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.89/reference/services/finspace-data.html#FinSpaceData.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/finspace-data.html#FinSpaceData.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/client.html#can_paginate)
         """
 
@@ -77,7 +77,7 @@ class FinSpaceDataClient:
         tags: Dict[str, str] = None
     ) -> CreateChangesetResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.89/reference/services/finspace-data.html#FinSpaceData.Client.create_changeset)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/finspace-data.html#FinSpaceData.Client.create_changeset)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/client.html#create_changeset)
         """
 
@@ -89,22 +89,22 @@ class FinSpaceDataClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.89/reference/services/finspace-data.html#FinSpaceData.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/finspace-data.html#FinSpaceData.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/client.html#generate_presigned_url)
         """
 
     def get_programmatic_access_credentials(
-        self, *, environmentId: str, durationInMinutes: int = None
+        self, environmentId: str, durationInMinutes: int = None
     ) -> GetProgrammaticAccessCredentialsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.89/reference/services/finspace-data.html#FinSpaceData.Client.get_programmatic_access_credentials)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/finspace-data.html#FinSpaceData.Client.get_programmatic_access_credentials)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/client.html#get_programmatic_access_credentials)
         """
 
     def get_working_location(
-        self, *, locationType: locationTypeType = None
+        self, locationType: locationTypeType = None
     ) -> GetWorkingLocationResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.89/reference/services/finspace-data.html#FinSpaceData.Client.get_working_location)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/finspace-data.html#FinSpaceData.Client.get_working_location)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/client.html#get_working_location)
         """
